#!/bin/bash

function exec_cmd()
{
	echo "executing $@"
	$@ >/dev/null 2>&1

	if [ $? -ne 0 ]; then
		echo "Failed to execute $@"
		exit 1
	fi
}

function install_bbfdmd()
{
	[ -d "/opt/dev/bbfdm" ] && rm -rf /opt/dev/bbfdm

	if [ -n "${BBFDM_BRANCH}" ]; then
		exec_cmd git clone -b ${BBFDM_BRANCH} https://dev.iopsys.eu/bbf/bbfdm.git /opt/dev/bbfdm
	else
		exec_cmd git clone https://dev.iopsys.eu/bbf/bbfdm.git /opt/dev/bbfdm
	fi

	cd /opt/dev/bbfdm
	exec_cmd ./gitlab-ci/install-dependencies.sh install
	exec_cmd ./gitlab-ci/setup.sh install
}

function install_nfqueue()
{
	exec_cmd sudo apt-get update
	sudo yes | apt-get install libnetfilter-queue-dev
	sudo yes | apt-get install iptables

	exec_cmd iptables -L FORWARD|grep -iqE "NFQUEUE"
	echo "Applying firewall rule to setup NFQUEUE on forward traffic for urlfiltering"
	exec_cmd iptables -I FORWARD -p tcp --dport 80 -j NFQUEUE --queue-num 0
}

function install_cmph()
{
	[ -d "/opt/dev/cmph" ] && rm -rf /opt/dev/cmph

	exec_cmd git clone https://git.code.sf.net/p/cmph/git /opt/dev/cmph

	cd /opt/dev/cmph
	exec_cmd autoreconf -i
	exec_cmd ./configure
	exec_cmd make
	exec_cmd sudo make install
}
